pub struct PassAdapter<'a, H: PhysicsHooks + ?Sized, E: EventHandler + ?Sized> { /* private fields */ }Trait Implementations
Sourceimpl<H, E> EventHandler for PassAdapter<'_, H, E>
impl<H, E> EventHandler for PassAdapter<'_, H, E>
Sourcefn handle_collision_event(
&self,
_bodies: &RigidBodySet,
_colliders: &ColliderSet,
event: CollisionEvent,
_contact_pair: Option<&ContactPair>,
)
fn handle_collision_event( &self, _bodies: &RigidBodySet, _colliders: &ColliderSet, event: CollisionEvent, _contact_pair: Option<&ContactPair>, )
Called when two colliders start or stop touching each other. Read more
Sourcefn handle_contact_force_event(
&self,
dt: f32,
_bodies: &RigidBodySet,
_colliders: &ColliderSet,
contact_pair: &ContactPair,
total_force_magnitude: f32,
)
fn handle_contact_force_event( &self, dt: f32, _bodies: &RigidBodySet, _colliders: &ColliderSet, contact_pair: &ContactPair, total_force_magnitude: f32, )
Called when contact forces exceed a threshold. Read more
Sourceimpl<H, E> PhysicsHooks for PassAdapter<'_, H, E>
impl<H, E> PhysicsHooks for PassAdapter<'_, H, E>
Sourcefn filter_contact_pair(
&self,
context: &PairFilterContext<'_>,
) -> Option<SolverFlags>
fn filter_contact_pair( &self, context: &PairFilterContext<'_>, ) -> Option<SolverFlags>
Applies the contact pair filter. Read more
Sourcefn filter_intersection_pair(&self, context: &PairFilterContext<'_>) -> bool
fn filter_intersection_pair(&self, context: &PairFilterContext<'_>) -> bool
Applies the intersection pair filter. Read more
Sourcefn modify_solver_contacts(&self, context: &mut ContactModificationContext<'_>)
fn modify_solver_contacts(&self, context: &mut ContactModificationContext<'_>)
Modifies the set of contacts seen by the constraints solver. Read more