pub struct ExtStressSolver { /* private fields */ }Expand description
High-level stress solver that manages NvBlast families, actors, and fracture commands.
This is the primary API for most users. It wraps the C++ ExtStressSolver which internally
manages an NvBlast asset, family, and actors alongside the stress computation.
Implementations
Sourceimpl ExtStressSolver
impl ExtStressSolver
Sourcepub fn new(
nodes: &[NodeDesc],
bonds: &[BondDesc],
settings: &SolverSettings,
) -> Option<Self>
pub fn new( nodes: &[NodeDesc], bonds: &[BondDesc], settings: &SolverSettings, ) -> Option<Self>
Create a solver from node and bond descriptors with the given settings.
Sourcepub fn set_settings(&mut self, settings: &SolverSettings)
pub fn set_settings(&mut self, settings: &SolverSettings)
Update solver settings.
Sourcepub fn add_force(
&mut self,
node_index: u32,
position: Vec3,
force: Vec3,
mode: ForceMode,
)
pub fn add_force( &mut self, node_index: u32, position: Vec3, force: Vec3, mode: ForceMode, )
Apply a force to a specific node.
Sourcepub fn add_gravity(&mut self, gravity: Vec3)
pub fn add_gravity(&mut self, gravity: Vec3)
Apply gravity to all actors.
Sourcepub fn add_actor_gravity(&mut self, actor_index: u32, gravity: Vec3) -> bool
pub fn add_actor_gravity(&mut self, actor_index: u32, gravity: Vec3) -> bool
Apply gravity to a specific actor.
Sourcepub fn overstressed_bond_count(&self) -> u32
pub fn overstressed_bond_count(&self) -> u32
Number of bonds that exceeded their fatal stress limit after the last update().
Sourcepub fn linear_error(&self) -> f32
pub fn linear_error(&self) -> f32
Linear error residual from the last solve.
Sourcepub fn angular_error(&self) -> f32
pub fn angular_error(&self) -> f32
Angular error residual from the last solve.
Sourcepub fn actor_count(&self) -> u32
pub fn actor_count(&self) -> u32
Number of actors currently in the family.
Sourcepub fn node_count(&self) -> u32
pub fn node_count(&self) -> u32
Total number of graph nodes.
Sourcepub fn bond_count(&self) -> u32
pub fn bond_count(&self) -> u32
Total number of bonds.
Sourcepub fn generate_fracture_commands(&self) -> Vec<FractureCommand>
pub fn generate_fracture_commands(&self) -> Vec<FractureCommand>
Generate fracture commands for all actors with overstressed bonds.
Sourcepub fn apply_fracture_commands(
&mut self,
commands: &[FractureCommand],
) -> Vec<SplitEvent>
pub fn apply_fracture_commands( &mut self, commands: &[FractureCommand], ) -> Vec<SplitEvent>
Apply fracture commands and return split events.